<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class exportacaoBalancaToledo extends CrudWithParameterBag {

    protected $ExportacaoBalancaToledo;
    protected $utilService;

    public function __construct(Manager $dataSourceManager, Services\ExportacaoBalancaToledo $ExportacaoBalancaToledo, Utilities\Util $utilService, ParameterBag $parameterBag) {
        $this->ExportacaoBalancaToledo = $ExportacaoBalancaToledo;
        $this->utilService = $utilService;
        parent::__construct($dataSourceManager, $parameterBag);
    }

    public function findReport(DTO\Request\Filter $request, DTO\Response $response) {

        $conditions = $this->utilService->getParamsAsArray($request);
        $this->buildParams($conditions);
        $result = $this->ExportacaoBalancaToledo->find($conditions['CDFILIAL'], $conditions['CDTABEPREC'], $conditions['LISTA'], $conditions['TODOS'], $conditions['CDARVPRODI'], $conditions['CDARVPRODF'], $conditions['IDPESAPROD']);
        $response->addDataSet(new DataSet("vnd44000_exportacaoBalancaToledo", $result));
        return $response;
    }

    public function buildParams(&$conditions){
        if(!isset($conditions['INTERVALISTA'])){
            $conditions['INTERVALISTA'] = null;
        }
        if ($conditions['INTERVALISTA'] == 'I') {
            $conditions['LISTA'] = null;
            $conditions['TODOS'] = null;

        }
        else if ($conditions['INTERVALISTA'] == 'L'){
            $conditions['LISTA'] = implode('_', $conditions['LISTA']);
            $conditions['TODOS'] = null;
            $conditions['CDARVPRODI'] = null;
            $conditions['CDARVPRODF'] = null;
        }
        else {
            $conditions['LISTA'] = null;
            $conditions['TODOS'] = $conditions['INTERVALISTA'];
            $conditions['CDARVPRODI'] = null;
            $conditions['CDARVPRODF'] = null;
        }
    }

    public function exportarArq(DTO\Request\Filter $request, Response $response) {
        $params     = $request->getParameters()["Filter"];
        $conditions = [];
        foreach ($params as $filter) {
            $conditions[$filter['name']] = $filter['value'];
        }
        $this->buildParams($conditions);
        $result = $this->ExportacaoBalancaToledo->find($conditions['CDFILIAL'], $conditions['CDTABEPREC'], $conditions['LISTA'], $conditions['TODOS'], $conditions['CDARVPRODI'], $conditions['CDARVPRODF'], $conditions['IDPESAPROD']);
        $text   = '';
        foreach ($result as $value) {
            $text .= $value['TEXTO'] . "\n";
        }

        $resultTXTINFO = $this->ExportacaoBalancaToledo->exportTXTINFO();
        $textTXTINFO   = '';
        foreach ($resultTXTINFO as $valueTXTINFO) {
            $textTXTINFO .= $valueTXTINFO['TEXTO'] . "\n";
        }

        $nomeArq      = 'ItensMgv';
        $nomeTXTINFO  = 'TXINFO';
        $nomeInfNutri = 'InfNutri';

        $return['texto']         = $text;
        $return['textotxinfo']   = $textTXTINFO;
        $return['InfNutri']      = ' ';
        $return['nome']          = $nomeArq;
        $return['nomeTXTINFO']   = $nomeTXTINFO;
        $return['nomeInfNutri']  = $nomeInfNutri;
        $return['error']         = false;


        $response->addDataSet(new DataSet('resultado', $return));
    }

    public function findInfoExtra(DTO\Request\Filter $request, DTO\Response $response) {

        $this->dataSourceName = "info_extra";
        parent::find($request, $response);
    }
    public function saveInfoExtra(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = "info_extra";
        $dataSet = $request->getDataSet();
        $rows = $dataSet->getRows();
        try {
    	    if($rows[0]['__is_new']) {
                $this->ExportacaoBalancaToledo->saveInfoExtra($rows);
    	    } else {
    	        $this->ExportacaoBalancaToledo->updateInfoExtra($rows);
    	    }
        } catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteInfoExtra(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $params = $this->utilService->getParamsAsArray($request);
            $this->ExportacaoBalancaToledo->deleteInfoExtra($params);
        } catch (\Exception $e) {
            $message = 'Não é possível remover uma informação que está atualmente atribuída à um produto!';
            $response->setError(new DTO\Response\Error($message, $e->getCode()));
        }
    }

    /**
     * Salva Cadastramento Automattico
     * @param Row $row
     * @param Response $response
     */
    public function salvaCadastramentoAutomatico(DTO\Request\Row $row, DTO\Response $response)
    {
        try {

            $row  = $row->getRow();
            $this->ExportacaoBalancaToledo->salvaCadastramentoAutomatico($row);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

}